@@ -1,7 +1,9 @@
 # PBSmapping utilities
 
 SpatialPolygons2PolySet <- function(SpP) {
-	require(PBSmapping)
+	# require(PBSmapping)
+    if (!requireNamespace("PBSmapping", quietly = TRUE))
+		stop("package PBSmapping required for SpatialPolygons2PolySet")
 	pls <- slot(SpP, "polygons")
 	n <- length(pls)
 	PID <- NULL
@@ -17,7 +19,10 @@ SpatialPolygons2PolySet <- function(SpP) {
 			k <- nrow(crds)
 			PID <- c(PID, rep(i, k))
 			SID <- c(SID, rep(j, k))
-			POS <- c(POS, 1:k)
+#			POS <- c(POS, 1:k)
+# Daniel Rodolphe Schlaepfer 140806
+			if(slot(srs[[j]], "hole")) POS <- c(POS, k:1) 
+			else POS <- c(POS, 1:k)
 			X <- c(X, crds[,1])
 			Y <- c(Y, crds[,2])
 		}
@@ -27,15 +32,14 @@ SpatialPolygons2PolySet <- function(SpP) {
 	POS <- as.integer(POS)
         storage.mode(X) <- "double"
         storage.mode(Y) <- "double"
-	require(PBSmapping)
 	pj <- .pbsproj(SpP)
 	zn <- NULL
 	if (pj == "UTM") {
 		zn <- attr(pj, "zone")
 		attr(pj, "zone") <- NULL
 	}
-	res <- as.PolySet(data.frame(PID=PID, SID=SID, POS=POS, X=X, Y=Y),
-		projection=pj, zone=zn)
+	res <- PBSmapping::as.PolySet(data.frame(PID=PID, SID=SID, POS=POS, 
+		X=X, Y=Y), projection=pj, zone=zn)
 	res
 }
 
@@ -66,15 +70,17 @@ SpatialLines2PolySet <- function(SL) {
 	POS <- as.integer(POS)
         storage.mode(X) <- "double"
         storage.mode(Y) <- "double"
-	require(PBSmapping)
+	# require(PBSmapping)
+    if (!requireNamespace("PBSmapping", quietly = TRUE))
+		stop("package PBSmapping required for SpatialPolygons2PolySet")
 	pj <- .pbsproj(SL)
 	zn <- NULL
 	if (pj == "UTM") {
 		zn <- attr(pj, "zone")
 		attr(pj, "zone") <- NULL
 	}
-	res <- as.PolySet(data.frame(PID=PID, SID=SID, POS=POS, X=X, Y=Y),
-		projection=pj, zone=zn)
+	res <- PBSmapping::as.PolySet(data.frame(PID=PID, SID=SID, POS=POS, 
+		X=X, Y=Y), projection=pj, zone=zn)
 	res
 }
 
@@ -82,7 +88,7 @@ SpatialLines2PolySet <- function(SL) {
 	p4str <- proj4string(Sobj)
 	if (is.na(p4str)) return("1")
 	res <- grep("longlat", p4str, fixed=TRUE)
-	if (length(res) > 0) return("LL")
+	if (length(res) > 0L) return("LL")
 	res <- regexpr("utm", p4str, fixed=TRUE)
 	if (res > 0) {
 		val <- "UTM"
@@ -106,7 +112,11 @@ PolySet2SpatialPolygons <- function(PS, close_polys=TRUE) {
         if (is.null(zn)) zn <- attr(PS, "zone")
         if (is.null(zn)) stop("no valid zone attribute")
 	p4s <- paste("+proj=utm +zone=", zn, sep="")
-    } else stop("unknown coordinate reference system")
+    } else {
+       p4s <- as.character(NA)
+       warning("unknown coordinate reference system")
+    }
+# stop("unknown coordinate reference system") 110310
     hasPID <- "PID" %in% names(PS)
     if (!hasPID) stop("object does not have PID column")
     res0 <- split(PS, PS$PID)
@@ -156,7 +166,11 @@ PolySet2SpatialLines <- function(PS) {
         if (is.null(zn)) zn <- attr(PS, "zone")
         if (is.null(zn)) stop("no valid zone attribute")
 	p4s <- paste("+proj=utm +zone=", zn, sep="")
-    } else stop("unknown coordinate reference system")
+    } else {
+       p4s <- as.character(NA)
+       warning("unknown coordinate reference system")
+    }
+# stop("unknown coordinate reference system") 110310
     hasPID <- "PID" %in% names(PS)
     if (!hasPID) stop("object does not have PID column")
     res0 <- split(PS, PS$PID)
@@ -176,8 +190,4 @@ PolySet2SpatialLines <- function(PS) {
     }
     outSP <- SpatialLines(outLines, proj4string=CRS(p4s))
     outSP
-    
-
 }
-
-
